@@ -139,23 +139,26 @@ gaim_xfer_conversation_write(GaimXfer *xfer, char *message, gboolean is_error)
 
 static void gaim_xfer_show_file_error(GaimXfer *xfer, const char *filename)
 {
-	gchar *msg = NULL;
+	int err = errno;
+	gchar *msg = NULL, *utf8;
 	GaimXferType xfer_type = gaim_xfer_get_type(xfer);
 
+	utf8 = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
 	switch(xfer_type) {
 		case GAIM_XFER_SEND:
 			msg = g_strdup_printf(_("Error reading %s: \n%s.\n"),
-								  filename, strerror(errno));
+								  utf8, strerror(err));
 			break;
 		case GAIM_XFER_RECEIVE:
 			msg = g_strdup_printf(_("Error writing %s: \n%s.\n"),
-								  filename, strerror(errno));
+								  utf8, strerror(err));
 			break;
 		default:
 			msg = g_strdup_printf(_("Error accessing %s: \n%s.\n"),
-								  filename, strerror(errno));
+								  utf8, strerror(err));
 			break;
-		}
+	}
+	g_free(utf8);
 
 	gaim_xfer_conversation_write(xfer, msg, TRUE);
 	gaim_xfer_error(xfer_type, xfer->who, msg);
@@ -200,8 +203,11 @@ gaim_xfer_choose_file_ok_cb(void *user_data, const char *filename)
 	}
 	else if ((gaim_xfer_get_type(xfer) == GAIM_XFER_RECEIVE) &&
 			 S_ISDIR(st.st_mode)) {
-				char *msg = g_strdup_printf(
-					_("%s is not a regular file. Cowardly refusing to overwrite it.\n"), filename);
+		char *utf8, *msg;
+		utf8 = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
+		msg = g_strdup_printf(
+					_("%s is not a regular file. Cowardly refusing to overwrite it.\n"), utf8);
+		g_free(utf8);
 		gaim_notify_error(NULL, NULL, msg, NULL);
 		g_free(msg);
 		gaim_xfer_request_denied(xfer);
@@ -354,13 +360,15 @@ gaim_xfer_request_accepted(GaimXfer *xfer, const char *filename)
 	}
 
 	if (type == GAIM_XFER_SEND) {
-		char *msg;
+		char *msg, *utf8;
 
 		/* Check the filename. */
 		if (g_strrstr(filename, "..")) {
+			char *utf8 = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
 
-			msg = g_strdup_printf(_("%s is not a valid filename.\n"), filename);
+			msg = g_strdup_printf(_("%s is not a valid filename.\n"), utf8);
 			gaim_xfer_error(type, xfer->who, msg);
+			g_free(utf8);
 			g_free(msg);
 
 			gaim_xfer_unref(xfer);
@@ -374,11 +382,14 @@ gaim_xfer_request_accepted(GaimXfer *xfer, const char *filename)
 		}
 
 		gaim_xfer_set_local_filename(xfer, filename);
-		gaim_xfer_set_filename(xfer, g_basename(filename));
 		gaim_xfer_set_size(xfer, st.st_size);
-		
+
+		utf8 = g_filename_to_utf8(g_basename(filename), -1, NULL, NULL, NULL);
+		gaim_xfer_set_filename(xfer, utf8);
+
 		msg = g_strdup_printf(_("Offering to send %s to %s"),
-							  filename, xfer->who);
+							  utf8, xfer->who);
+		g_free(utf8);
 		gaim_xfer_conversation_write(xfer, msg, FALSE);
 		g_free(msg);
 	}
