@@ -72,6 +72,7 @@ static struct developer developers[] = {
 	{"Luke 'LSchiere' Schierer",	N_("support"), "lschiere@users.sf.net"},
 	{"Stu 'nosnilmot' Tomlinson",	N_("developer"), NULL},
 	{"Gary 'grim' Kramlich",		N_("developer"), NULL},
+	{"Richard 'rlaager' Laager",	N_("developer"), NULL},
 	{NULL, NULL, NULL}
 };
 
@@ -79,6 +80,7 @@ static struct developer patch_writers[] = {
 	{"Ka-Hing 'javabsp' Cheung",	NULL,	NULL},
 	{"Felipe 'shx' Contreras",		NULL,	NULL},
 	{"Decklin Foster",				NULL,	NULL},
+	{"Peter 'Bleeter' Lawler",      NULL,   NULL},
 	{"Robert 'Robot101' McQueen",	NULL,	NULL},
 	{"Benjamin Miller",				NULL,	NULL},
 	{"Kevin 'SimGuy' Stange",		NULL,	NULL},
@@ -112,7 +114,7 @@ static struct translator current_translators[] = {
 	{N_("French"),				"fr", "Éric Boumaour", "zongo_fr@users.sourceforge.net"},
 	{N_("Hebrew"),				"he", "Pavel Bibergal", "cyberkm203@hotmail.com"},
 	{N_("Hindi"),				"hi", "Akash Mahajan", "akashm@users.sf.net"},
-	{N_("Hungarian"),			"hu", "Zoltan Sutto", "sutto.zoltan@rutinsoft.hu"},
+	{N_("Hungarian"),			"hu", "Gabor Kelemen", "kelemeng@gnome.hu"},
 	{N_("Italian"),				"it", "Claudio Satriano", "satriano@na.infn.it"},
 	{N_("Japanese"),			"ja", "Takashi Aihana", "aihana@gnome.gr.jp"},
 	{N_("Georgian"),            "ka", "Temuri Doghonadze", "admin@security.gov.ge"},
@@ -121,12 +123,13 @@ static struct translator current_translators[] = {
 	{N_("Macedonian"),			"mk", "Tomislav Markovski", "herrera@users.sf.net"},
 	{N_("Burmese"),             "my_MM", "Minn Myat Soe", "mmyatsoe@gmail.com"},
 	{N_("Dutch; Flemish"),		"nl", "Vincent van Adrighem", "V.vanAdrighem@dirck.mine.nu"},
+	{N_("Norwegian (Nynorsk)"), "nn", "Kurt-Rune Bergset", ""},
 	{N_("Norwegian"),			"no", "Kyrre Ness Sjøbæk", "kyrsjo@users.sf.net"},
 	{N_("Punjabi"),             "pa", "Amanpreet Singh Alam", "aalam@redhat.com"},
 	{N_("Polish"),				"pl", "Krzysztof Foltman, Emil Nowak", "krzysztof@foltman.com;emil5@go2.pl"},
 	{N_("Portuguese"),			"pt", "Duarte Henriques", "duarte_henriques@myrealbox.com"},
 	{N_("Portuguese-Brazil"),	"pt_BR", "Maurício de Lemos Rodrigues Collares Neto", "mauricioc@gmail.com"},
-	{N_("Romanian"),			"ro", "Mişu Moldovan", "dumol@go.ro"},
+	{N_("Romanian"),			"ro", "Mişu Moldovan", "dumol@gnome.ro"},
 	{N_("Russian"),				"ru", "Dmitry Beloglazov", "dmaa@users.sf.net"},
 	{N_("Slovenian"),			"sl", "Martin Srebotnjak", "miles@filmsi.net"},
 	{N_("Albanian"),            "sq", "Programe Shqip", "besnik@spymac.com"},
@@ -152,6 +155,7 @@ static struct translator past_translators[] = {
 	{N_("Finnish"),				"fi", "Tero Kuusela", NULL},
 	{N_("French"),				"fr", "Sébastien François, Stéphane Pontier, Stéphane Wirtel, Loïc Jeannin", NULL},
 	{N_("Hindi"),				"hi", "Ravishankar Shrivastava", "raviratlami@yahoo.com"},
+	{N_("Hungarian"),			"hu", "Zoltan Sutto", NULL},
 	{N_("Italian"),				"it", "Salvatore di Maggio", NULL},
 	{N_("Japanese"),			"ja", "Ryosuke Kutsuna, Taku Yasui, Junichi Uekawa", NULL},
 	{N_("Korean"),				"ko", "Sang-hyun S, A Ho-seok Lee", NULL},
@@ -160,7 +164,7 @@ static struct translator past_translators[] = {
 	{N_("Russian"),				"ru", "Sergey Volozhanin", NULL},
 	{N_("Russian"),				"ru", "Alexandre Prokoudine", NULL},
 	{N_("Slovak"),				"sk", "Daniel Režný", NULL},
-	{N_("Swedish"),				"sv", "Tore Lundqvist", "tlt@mima.x.se"},
+	{N_("Swedish"),				"sv", "Tore Lundqvist", NULL},
 	{N_("Swedish"),				"sv", "Christian Rose", NULL},
 	{N_("Chinese"),				"zh_CN, zh_TW", "Hashao, Rocky S. Lee", NULL},
 	{NULL, NULL, NULL, NULL}
